package com.jclark.xml.output;

import java.io.Writer;
import java.io.IOException;

/**
 * An extension of <code>Writer</code> for writing XML documents.
 * The normal <code>write</code> methods write character data,
 * automatically escaping markup characters.
 */

public abstract class XMLWriter extends Writer {

  protected XMLWriter(Object lock) {
    super(lock);
  }

  /**
   * Start an element.
   * This may be followed by zero or more calls to <code>attribute</code>.
   * The start-tag will be closed by the first following call to any method
   * other than <code>attribute</code>.
   */
  public abstract void startElement(String name) throws IOException;

  /**
   * Write an attribute.
   * This is not legal if there have been calls to methods other than
   * <code>attribute</code> since the last call to <code>startElement</code>.
   */
  public abstract void attribute(String name, String value) throws IOException;

  /**
   * End an element.
   * This may output an end-tag or close the current start-tag as an
   * empty element.
   */
  public abstract void endElement(String name) throws IOException;

  /**
   * Write a processing instruction.
   * If <code>data</code> is non-empty a space will be inserted automatically
   * to separate it from the <code>target</code>.
   */
  public abstract void processingInstruction(String target, String data) throws IOException;

  /**
   * Write markup.  The characters in the string will be written as is
   * without being escaped.
   */
  public abstract void markup(String str) throws IOException;
}
